==> koha-21.05.04.tar.gz: koha-21.05.04/installer/data/mysql/mandatory/sample_notices_message_transports.sql <==
insert into `message_transports`
(`message_attribute_id`, `message_transport_type`, `is_digest`, `letter_module`, `letter_code`)
values
(1, 'email', 0, 'circulation', 'DUE'),
(1, 'email', 1, 'circulation', 'DUEDGST'),
(1, 'sms',   0, 'circulation', 'DUE'),
(1, 'sms',   1, 'circulation', 'DUEDGST'),
(1, 'phone', 0, 'circulation', 'DUE'),
(1, 'phone', 1, 'circulation', 'DUEDGST'),
(2, 'email', 0, 'circulation', 'PREDUE'),
(2, 'email', 1, 'circulation', 'PREDUEDGST'),
(2, 'sms',   0, 'circulation', 'PREDUE'),
(2, 'sms',   1, 'circulation', 'PREDUEDGST'),
(2, 'phone', 0, 'circulation', 'PREDUE'),
(2, 'phone', 1, 'circulation', 'PREDUEDGST'),
(2, 'itiva', 0, 'circulation', 'PREDUE'),
(2, 'itiva', 1, 'circulation', 'PREDUEDGST'),
(4, 'email', 0, 'reserves',    'HOLD'),
(4, 'sms',   0, 'reserves',    'HOLD'),
(4, 'phone', 0, 'reserves',    'HOLD'),
(4, 'itiva', 0, 'reserves',    'HOLD'),
(5, 'email', 0, 'circulation', 'CHECKIN'),
(5, 'sms',   0, 'circulation', 'CHECKIN'),
(5, 'phone', 0, 'circulation', 'CHECKIN'),
(6, 'email', 0, 'circulation', 'CHECKOUT'),
(6, 'sms',   0, 'circulation', 'CHECKOUT'),
(6, 'phone', 0, 'circulation', 'CHECKOUT'),
(7, 'email', 0, 'ill', 'ILL_PICKUP_READY'),
(7, 'sms',   0, 'ill', 'ILL_PICKUP_READY'),
(7, 'phone', 0, 'ill', 'ILL_PICKUP_READY'),
(8, 'email', 0, 'ill', 'ILL_REQUEST_UNAVAIL'),
(8, 'sms',   0, 'ill', 'ILL_REQUEST_UNAVAIL'),
(8, 'phone', 0, 'ill', 'ILL_REQUEST_UNAVAIL'),
(9, 'email', 0, 'circulation', 'AUTO_RENEWALS'),
(9, 'sms',   0, 'circulation', 'AUTO_RENEWALS'),
(9, 'email', 1, 'circulation', 'AUTO_RENEWALS_DGST'),
(9, 'sms',   1, 'circulation', 'AUTO_RENEWALS_DGST');

==> koha-22.05.10.tar.gz: koha-22.05.10/installer/data/mysql/mandatory/sample_notices_message_transports.sql <==
insert into `message_transports`
(`message_attribute_id`, `message_transport_type`, `is_digest`, `letter_module`, `letter_code`)
values
(1, 'email', 0, 'circulation', 'DUE'),
(1, 'email', 1, 'circulation', 'DUEDGST'),
(1, 'sms',   0, 'circulation', 'DUE'),
(1, 'sms',   1, 'circulation', 'DUEDGST'),
(1, 'phone', 0, 'circulation', 'DUE'),
(1, 'phone', 1, 'circulation', 'DUEDGST'),
(2, 'email', 0, 'circulation', 'PREDUE'),
(2, 'email', 1, 'circulation', 'PREDUEDGST'),
(2, 'sms',   0, 'circulation', 'PREDUE'),
(2, 'sms',   1, 'circulation', 'PREDUEDGST'),
(2, 'phone', 0, 'circulation', 'PREDUE'),
(2, 'phone', 1, 'circulation', 'PREDUEDGST'),
(2, 'itiva', 0, 'circulation', 'PREDUE'),
(2, 'itiva', 1, 'circulation', 'PREDUEDGST'),
(4, 'email', 0, 'reserves',    'HOLD'),
(4, 'sms',   0, 'reserves',    'HOLD'),
(4, 'phone', 0, 'reserves',    'HOLD'),
(4, 'itiva', 0, 'reserves',    'HOLD'),
(5, 'email', 0, 'circulation', 'CHECKIN'),
(5, 'sms',   0, 'circulation', 'CHECKIN'),
(5, 'phone', 0, 'circulation', 'CHECKIN'),
(6, 'email', 0, 'circulation', 'CHECKOUT'),
(6, 'sms',   0, 'circulation', 'CHECKOUT'),
(6, 'phone', 0, 'circulation', 'CHECKOUT'),
(7, 'email', 0, 'ill', 'ILL_PICKUP_READY'),
(7, 'sms',   0, 'ill', 'ILL_PICKUP_READY'),
(7, 'phone', 0, 'ill', 'ILL_PICKUP_READY'),
(8, 'email', 0, 'ill', 'ILL_REQUEST_UNAVAIL'),
(8, 'sms',   0, 'ill', 'ILL_REQUEST_UNAVAIL'),
(8, 'phone', 0, 'ill', 'ILL_REQUEST_UNAVAIL'),
(9, 'email', 0, 'circulation', 'AUTO_RENEWALS'),
(9, 'sms',   0, 'circulation', 'AUTO_RENEWALS'),
(9, 'email', 1, 'circulation', 'AUTO_RENEWALS_DGST'),
(9, 'sms',   1, 'circulation', 'AUTO_RENEWALS_DGST'),
(10, 'email', 0, 'circulation', 'HOLD_REMINDER'),
(10, 'sms',   0, 'circulation', 'HOLD_REMINDER'),
(10, 'phone', 0, 'circulation', 'HOLD_REMINDER'),
(10, 'itiva', 0, 'circulation', 'HOLD_REMINDER');
